@@ -22,6 +22,7 @@ following functions are provided:
    isFirstLevelAnalysis
    loadDesign
    loadContrasts
+   loadFsf
    loadSettings
    getThresholds
    loadClusterResults
@@ -216,17 +217,16 @@ def loadContrasts(featdir):
     return names, contrasts
 
 
-def loadSettings(featdir):
-    """Loads the analysis settings from a FEAT directory.
+def loadFsf(designfsf):
+    """Loads the analysis settings from a text file (.fsf) used to configure
+    FEAT.
 
-    Returns a dict containing the settings specified in the ``design.fsf``
-    file within the directory
+    Returns a dict containing the settings specified in the file
 
-    :arg featdir: A FEAT directory.
+    :arg designfsf: A .fsf file.
     """
 
     settings  = collections.OrderedDict()
-    designfsf = op.join(featdir, 'design.fsf')
 
     log.debug('Loading FEAT settings from {}'.format(designfsf))
 
@@ -251,6 +251,20 @@ def loadSettings(featdir):
     return settings
 
 
+def loadSettings(featdir):
+    """Loads the analysis settings from a FEAT directory.
+
+    Returns a dict containing the settings specified in the ``design.fsf``
+    file within the directory
+
+    :arg featdir: A FEAT directory.
+    """
+
+    designfsf = op.join(featdir, 'design.fsf')
+
+    return loadFsf(designfsf)
+
+
 def loadDesign(featdir, settings):
     """Loads the design matrix from a FEAT directory.
 
